def git_sha():
    """ Gets the git revision, if it exists in cwd """
    try:
        from .__sha__ import __sha__
    except Exception as e1:
        from .settings import TESTING
        if not TESTING:
            print(repr(e1))
        import subprocess

        try:
            __sha__ = (
                subprocess.check_output(["git", "rev-parse", "--short", "HEAD"])
                .decode()
                .rstrip()
            )
        except Exception as e2:
            print(repr(e2))
            __sha__ = None

    return __sha__


# Export for package level
__sha__ = git_sha()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sat Jul 18 16:16:08 2020

@author: shane
"""

import csv

from tabulate import tabulate

from .utils import remote


def list_nutrients():
    response = remote.request("/nutrients")
    results = response.json()["data"]

    table = tabulate(results, headers="keys", tablefmt="presto")
    print(table)
    return table


def sort_foods_by_nutrient_id(id):
    response = remote.request("/foods/sort", params={"nutr_id": id})
    results = response.json()["data"]

    table = tabulate(results, headers="keys", tablefmt="presto")
    print(table)
    return table


def sort_foods_by_kcal_nutrient_id(id):
    pass


def day_analyze(day_csv, rda_csv=None):
    day_csv_input = csv.DictReader(day_csv)

    log = []
    for row in day_csv_input:
        log.append(row)

    rda = []
    if rda_csv:
        rda_csv_input = csv.DictReader(rda_csv)
        for row in rda_csv_input:
            rda.append(row)

    response = remote.request("/day/analyze", body={"log": log, "rda": rda})
    results = response.json()["data"]

    totals = results["nutrient_totals"]
    print(totals)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sat Jul 18 16:13:45 2020

@author: shane
"""

import os

from .usda import (
    day_analyze,
    list_nutrients,
    sort_foods_by_kcal_nutrient_id,
    sort_foods_by_nutrient_id,
)


def nutrients(args, unknown, arg_parser=None):
    return list_nutrients()


def search():
    pass


def sort(args, unknown, arg_parser=None):
    # TODO: --kcal or -c, option for sorting by kcal
    nutr_id = int(unknown[0])
    return sort_foods_by_nutrient_id(nutr_id)


def analyze():
    pass


def day(args, unknown, arg_parser=None):
    # TODO: rda.csv argument
    day_path = os.path.expanduser(unknown[0])
    day_csv = open(day_path)
    rda_csv = None
    if len(unknown) > 1:
        rda_path = os.path.expanduser(unknown[1])
        rda_csv = open(rda_path)
    return day_analyze(day_csv, rda_csv=rda_csv)
